@@ -115,14 +115,17 @@ class Batch:
     def batch(self):
         return self.__batch
 
-    @with_retries(success_max=1)
     async def send(self):
+        @with_retries(success_max=1)
+        async def __send():
+            await self.__batch.send()
+
         for entry in self.__cas_keys:
             entry_cas = await KVClient.get_entry_with_version(self.__session, **entry)
             new_value = entry.get('new_value')
             entry_cas.cas(new_value=new_value, batch=self.__batch)
         await asyncio.sleep(0)
-        await self.__batch.send()
+        await __send()
 
     def set(self, partition_key: List[str], new_value: object, clustering_key: Optional[List[str]] = None):
         entry = self.__session.entry(partition_key, clustering_key)
@@ -178,6 +181,7 @@ class KVClient:
         )
 
     @staticmethod
+    @with_retries(success_max=1)
     async def get_entry_with_version(
             session: Session,
             partition_key: List[str],
